@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Document;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: One JSON Schema document
 
-our $VERSION = '0.619';
+our $VERSION = '0.620';
 
 use 5.020;
 use Moo;
@@ -195,7 +195,7 @@ sub traverse ($self, $evaluator, $config_override = {}) {
   my $state = $evaluator->traverse($self->schema,
     {
       initial_schema_uri => $original_uri,
-      $self->_has_metaschema_uri ? ( metaschema_uri => $self->metaschema_uri ) : (),
+      $self->_has_metaschema_uri ? (metaschema_uri => $self->metaschema_uri) : (),
       %$config_override,
     }
   );
@@ -263,7 +263,7 @@ JSON::Schema::Modern::Document - One JSON Schema document
 
 =head1 VERSION
 
-version 0.619
+version 0.620
 
 =head1 SYNOPSIS
 
@@ -453,6 +453,14 @@ L<Mojo::JSON::Pointer>
 
 =back
 
+=head1 GIVING THANKS
+
+=for stopwords MetaCPAN GitHub
+
+If you found this module to be useful, please show your appreciation by
+adding a +1 in L<MetaCPAN|https://metacpan.org/dist/JSON-Schema-Modern>
+and a star in L<GitHub|https://github.com/karenetheridge/JSON-Schema-Modern>.
+
 =head1 SUPPORT
 
 Bugs may be submitted through L<https://github.com/karenetheridge/JSON-Schema-Modern/issues>.
